///////////////////////////////////////////////////////////////////////////////
// Utilisation simplifie d'un cran LCD  2 lignes et 16 colonnes
//
// IUT de Cachan
// Version 11/2015 pour xc8
// Source inspir des bibliothques de Microchip MPLAB C18
//
// Fonctions disponibles
//
//   void lcd_init(void);
//     Initialisation de l'cran LCD.
//     Cette fonction configure l'cran LCD.
//     
//   void lcd_clear(void);
//     Efface l'cran.
//
//   void lcd_position(char ligne, char colonne);
//     Positionne le curseur pour l'affichage.
//     Le coin suprieur gauche est en (0,0).
//       colonne 0                    colonne 15
//               |                             |
//     ligne 0 - X X X X X X X X X X X X X X X X
//
//     ligne 1 - X X X X X X X X X X X X X X X X
//
//   void lcd_putc(unsigned char lettre);
//     Affiche un caractre  la position du curseur.
//     Le curseur se dcale d'une case vers la droite.
//     Les caractres spciaux sont interprts (voir ci-dessous).
//
//   int lcd_printf(const char *f, ...);
//     Fonction printf pour l'cran LCD.
//     Pour une description complte des formats autoriss,
//     voir MPLAB_C18_Libraries_51297f.pdf 4.7
//
// Caractres spciaux interprts :
//   \n  passe  la ligne (ne fonctionne que de la ligne 0  la ligne 1)
//   \b  pour reculer le curseur d'une case
//   \f  pour effacer l'cran
//
// Connexions :
//   Broche - Ecran LCD
//     D0   -    E
//     D1   -    RS
//     D2   -    RW
//     D3   -    non connecte
//   D4-D7  -    Data[4..7]
//
///////////////////////////////////////////////////////////////////////////////

#include <xc.h>

///////////////////////////////////////////////////////////////////////////////
//  Nom de fonction  :  lcd_init
//  Valeur de retour :  aucune
//  Paramtres       :  aucun
//  Description      :  base sur le coontroleur d'afficheur Hitachi HD44780
//                      cette fonction initialise l'cran LCD
///////////////////////////////////////////////////////////////////////////////
void lcd_init(void);

///////////////////////////////////////////////////////////////////////////////
//  Nom de fonction  :  lcd_clear
//  Valeur de retour :  aucune
//  Paramtres       :  aucun
//  Description      :  efface l'cran LCD
///////////////////////////////////////////////////////////////////////////////
void lcd_clear(void);

///////////////////////////////////////////////////////////////////////////////
//  Nom de fonction  :  lcd_position
//  Valeur de retour :  aucune
//  Paramtres       :  char ligne
//                        numro de la ligne (0 ou 1)
//                      char colonne
//                        numro de la colonne (de 0  15)
//  Description      :  place le curseur sur la case (ligne, colonne)
///////////////////////////////////////////////////////////////////////////////
void lcd_position(char ligne, char colonne);

///////////////////////////////////////////////////////////////////////////////
//  Nom de fonction  :  lcd_putc
//  Valeur de retour :  aucune
//  Paramtres       :  unsigned char lettre
//                        code ASCII du caractre  afficher
//  Description      :  affiche un caractre sur l'cran en grant les
//                      caractres spciaux \n \f \b
///////////////////////////////////////////////////////////////////////////////
void lcd_putc(unsigned char lettre);

///////////////////////////////////////////////////////////////////////////////
//  Nom de fonction  :  lcd_printf
//  Valeur de retour :  aucune
//  Paramtres       :  const char *f
//                        chaine de format
//                        pour une description complte des formats autoriss,
//                        voir MPLAB_C18_Libraries_51297f.pdf 4.7
//                        le format float (%f) est partiellement implment
//                      ...
//                        variables  convertir
//  Description      :  affiche un message sur l'cran LCD
///////////////////////////////////////////////////////////////////////////////
void lcd_printf(const char *f, ...);


///////////////////////////////////////////////////////////////////////////////
//
// Obsoltes
// Fournies pour compatibilit avec la version prcdente de la bibliothque.
//
///////////////////////////////////////////////////////////////////////////////
void lcd_gotoyx(char ligne, char colonne);
void lcd_puti(int nombre);
void lcd_putrs(const char *chaine);
void lcd_puts(char *chaine);

